@@ -1,6 +1,6 @@
 import os
 import sys
-import mc3_integration.settings.local as local
+import cleargrid.mc3_integration.settings.local as local
 
 
 def get_setting(name, default=None):
